/* This file is part of Zanshin

   Copyright 2015 Sandro Knauß <sknauss@kde.org>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
   published by the Free Software Foundation; either version 2 of
   the License or (at your option) version 3 or any later version
   accepted by the membership of KDE e.V. (or its successor approved
   by the membership of KDE e.V.), which shall act as a proxy
   defined in Section 14 of version 3 of the license.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
   USA.
*/

#ifndef WIDGETS_PRINTWIDGET_H
#define WIDGETS_PRINTWIDGET_H

#include <QWidget>

#include <QSharedPointer>

#include <functional>

#include "domain/artifact.h"
#include "domain/task.h"

class QLineEdit;
class QModelIndex;
class QTreeView;
class QMessageBox;
class QMenu;
class QTextDocument;
class QTextEdit;
class QTimer;
class QPrinter;

namespace Akonadi {
    class TaskRepository;
    class TaskQueries;
}

namespace Grantlee {
    class Engine;
}

namespace Widgets {

class PrintWidget : public QWidget
{
    Q_OBJECT
public:
    enum ApplicationMode {
        TasksOnly,
        NotesOnly,
        TasksAndNotes
    };
    explicit PrintWidget(QWidget *parent = 0, ApplicationMode mode = TasksAndNotes);

    QObject *model() const;

    void print(QPrinter *printer);

signals:
    void init();

public slots:
    void setModel(QObject *model);
    void print(QObject *model, QPrinter *printer);

private:
    QObject *m_model;
    QTextDocument *m_document;
    QTextEdit *m_edit;
    QTimer *m_timer;
    ApplicationMode m_mode;
    bool m_init;

    Akonadi::TaskRepository *m_repository;
    Akonadi::TaskQueries *m_queries;
    Grantlee::Engine *m_engine;
private slots:
    void render();
    void delayedInit();

private:
    QString renderItem(const Domain::Task::Ptr &task);
};

}

#endif // WIDGETS_PRINTWIDGET_H
